"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.withDevTools = void 0;

var _constants = require("./constants");

var _createDevTools = require("./createDevTools");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { keys.push.apply(keys, Object.getOwnPropertySymbols(object)); } if (enumerableOnly) keys = keys.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

/**
 *
 * @param {Function} reducer a function which takes state and action to return a next state
 * @param {Object} options options to configure Redux Dev Tools
 * @return {Function} an enhanced reducer, which will send actions and next states to Redux
 * Dev Tools. By default it connects in development and production NODE_ENVs
 */
var withDevTools = function withDevTools(reducer) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  var _options$envs = options.envs,
      envs = _options$envs === void 0 ? ["development", "production"] : _options$envs,
      _options$init = options.init,
      init = _options$init === void 0 ? "".concat(_constants.DEVTOOLS, "/").concat(_constants.INIT) : _options$init,
      rest = _objectWithoutProperties(options, ["envs", "init"]);

  var envFlag = envs.includes(process.env.NODE_ENV);
  var extension = (0, _createDevTools.setDevTools)(envFlag);
  var devTools = extension.connect(_objectSpread({}, rest));
  devTools.send(init, reducer(undefined, {}));
  return function (state, action) {
    var nextState = reducer(state, action);
    devTools.send(action.type, nextState);
    return nextState;
  };
};

exports.withDevTools = withDevTools;
var _default = withDevTools;
exports["default"] = _default;